@@ -1,11 +1,16 @@
+from typing import TYPE_CHECKING, cast
+
 from .base import BaseKey
-
 from ..models.key import KeyModel
-
 from ..decorators import authorize_required
 
+if TYPE_CHECKING:
+    from .. import Awaiting
+
 
 class AwaitingKey(BaseKey):
+    _context: "Awaiting"
+
     @authorize_required
     async def delete(self) -> KeyModel:
         """Used delete key.
@@ -17,9 +22,12 @@ class AwaitingKey(BaseKey):
         """
 
         return KeyModel(
-            await self.context._post(
-                url=self.context._routes.key.delete,
-                json={"applicationKeyId": self.key_id},
-                include_account=False
+            cast(
+                dict,
+                await self._context._post(
+                    url=self._context._routes.key.delete,
+                    json={"applicationKeyId": self.key_id},
+                    include_account=False
+                )
             )
         )
