@@ -21,14 +21,13 @@ class KeyModel:
         self.application_key_id = data["applicationKeyId"]
         self.capabilities = data["capabilities"]
         self.account_id = data["accountId"]
-
-        if data["expirationTimestamp"]:
+        if ("expirationTimestamp" in data and
+                data["expirationTimestamp"] is not None):
             self.expires = datetime.utcfromtimestamp(
                 data["expirationTimestamp"] / 1000
             )
         else:
             self.expires = None
-
         self.bucket_id = data["bucketId"]
         self.name_prefix = data["namePrefix"]
         self.options = data["options"]
